<?php

/**
 * Copyright 2014 SURFnet bv
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace Surfnet\SamlBundle\DependencyInjection\Compiler;

use Symfony\Component\Config\Definition\Exception\InvalidConfigurationException;
use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
use Symfony\Component\DependencyInjection\ContainerBuilder;

class SpRepositoryAliasCompilerPass implements CompilerPassInterface
{
    public function process(ContainerBuilder $container)
    {
        if (!$container->hasParameter('surfnet_saml.configuration.service_provider_repository.alias')) {
            return;
        }

        $alias = $container->getParameter('surfnet_saml.configuration.service_provider_repository.alias');

        if (!$container->hasDefinition($alias)) {
            throw new InvalidConfigurationException(sprintf(
                'The container does not contain the configured entity repository service "%s"',
                $alias
            ));
        }

        $container->setAlias('surfnet_saml.entity.entity_repository', $alias);
    }
}
